import { useCallback, useState } from 'react';
import reactLogo from './assets/react.svg';
import { invoke } from '@tauri-apps/api/tauri';
import './App.css';
import clsx from 'clsx';

function App() {
  const [greetMsg, setGreetMsg] = useState('');
  const [name, setName] = useState('');
  const [screenshots, setScreenshots] = useState<string[]>([]);
  const [ledStripColors, setLedStripColors] = useState<string[]>([]);
  const [flowingLightMode, setFlowingLightMode] = useState<boolean>(false);

  async function greet() {
    // Learn more about Tauri commands at https://tauri.app/v1/guides/features/command
    setGreetMsg(await invoke('greet', { name }));
  }

  async function takeSnapshot() {
    const base64TextList: string[] = await invoke('take_snapshot');

    setScreenshots(base64TextList.map((text) => `data:image/webp;base64,${text}`));
  }

  const refreshDisplays = useCallback(async () => {
    await invoke('refresh_displays');
  }, []);

  const getLedStripColors = useCallback(async () => {
    setLedStripColors(await invoke('get_led_strip_colors'));
  }, []);

  const switchFlowingLightMode = useCallback(async () => {
    console.log('A', flowingLightMode);
    if (flowingLightMode) {
      await invoke('stop_flowing_light');
    } else {
      invoke('play_flowing_light');
    }
    console.log('B', flowingLightMode);
    setFlowingLightMode(!flowingLightMode);
  }, [flowingLightMode]);

  return (
    <div>
      <div className="flex justify-between">
        {ledStripColors.map((it) => (
          <span className=" h-8 flex-auto" style={{ backgroundColor: it }}></span>
        ))}
      </div>

      <div className="flex gap-1 justify-center w-screen overflow-hidden">
        {screenshots.map((screenshot) => (
          <div className="flex-auto">
            <img src={screenshot} />
          </div>
        ))}
      </div>

      <div className="flex gap-5 justify-center ">
        <button
          className="bg-black bg-opacity-20"
          type="button"
          onClick={() => refreshDisplays()}
        >
          Refresh Displays
        </button>
        <button
          className="bg-black bg-opacity-20"
          type="button"
          onClick={() => takeSnapshot()}
        >
          Take Snapshot
        </button>
        <button
          className="bg-black bg-opacity-20"
          type="button"
          onClick={() => getLedStripColors()}
        >
          Get Colors
        </button>
        <button
          className={clsx('bg-black', 'bg-opacity-20', {
            'bg-gradient-to-r from-purple-500 to-blue-500': flowingLightMode,
          })}
          type="button"
          onClick={() => switchFlowingLightMode()}
        >
          Flowing Light
        </button>
      </div>

      <div className="flex gap-5 justify-center">
        <img src="/vite.svg" className="logo vite" alt="Vite logo" />
        <img src="/tauri.svg" className="logo tauri" alt="Tauri logo" />
        <img src={reactLogo} className="logo react" alt="React logo" />
      </div>
    </div>
  );
}

export default App;
